@@ -7,14 +7,14 @@ use strict;
 
 package XML::Compile::SOAP::Util;
 use vars '$VERSION';
-$VERSION = '3.02';
+$VERSION = '3.03';
 
 use base 'Exporter';
 
 my @soap10 = qw/SOAP11HTTP WSDL11HTTP WSDL11MIME SOAP11ENV/;
 my @soap11 = qw/SOAP11ENV SOAP11ENC SOAP11NEXT SOAP11HTTP WSDL11SOAP/;
 my @wsdl11 = qw/WSDL11 WSDL11SOAP WSDL11HTTP WSDL11MIME WSDL11SOAP12/;
-my @daemon = qw/MSEXT/;
+my @daemon = qw/MSEXT XC_DAEMON_NS/;
 my @xop10  = qw/XOP10 XMIME10 XMIME11/;
 
 our @EXPORT_OK = (@soap10, @soap11, @wsdl11, @daemon, @xop10);
@@ -45,7 +45,11 @@ use constant
   };
  
 
-use constant MSEXT          => SOAP11ENV;
+use constant
+  { MSEXT           => SOAP11ENV
+  , XS_DAEMON_NS    => 'http://perl.org/xml-schemas/xml-compile-daemon/1.0'
+  };
+
 
 
 use constant
